@@ -79,7 +79,6 @@
 #include <errno.h>
 #include <sys/resource.h>
 #include <kdefakes.h>
-#include <QStandardPaths>
 
 #include "fishcode.h"
 
@@ -128,7 +127,7 @@ static KProcess *childPid = 0;
 using namespace KIO;
 extern "C" {
 
-int Q_DECL_EXPORT kdemain( int argc, char **argv )
+int KDE_EXPORT kdemain( int argc, char **argv )
 {
     QCoreApplication app(argc, argv);
     KComponentData componentData("fish", "kio_fish");
@@ -242,11 +241,11 @@ fishProtocol::fishProtocol(const QByteArray &pool_socket, const QByteArray &app_
 #ifdef Q_WS_WIN
         sshPath = strdup(QFile::encodeName(KStandardDirs::findExe("plink")));
 #else
-        sshPath = strdup(QFile::encodeName(QStandardPaths::findExecutable("ssh")));
+        sshPath = strdup(QFile::encodeName(KStandardDirs::findExe("ssh")));
 #endif
     }
     if (suPath == NULL) {
-        suPath = strdup(QFile::encodeName(QStandardPaths::findExecutable("su")));
+        suPath = strdup(QFile::encodeName(KStandardDirs::findExe("su")));
     }
     childPid = 0;
     connectionPort = 0;
@@ -260,7 +259,7 @@ fishProtocol::fishProtocol(const QByteArray &pool_socket, const QByteArray &app_
     recvLen = -1;
     sendLen = -1;
     connectionAuth.keepPassword = true;
-    connectionAuth.url.setScheme("fish");
+    connectionAuth.url.setProtocol("fish");
     outBufPos = -1;
     outBuf = NULL;
     outBufLen = 0;
@@ -707,11 +706,11 @@ int fishProtocol::establishConnection(const QByteArray &buffer) {
     return buf.length();
 }
 
-void fishProtocol::setHostInternal(const QUrl & u){
+void fishProtocol::setHostInternal(const KUrl & u){
   int port = u.port();
   if(port <= 0 ) // no port is -1 in QUrl, but in kde3 we used 0 and the kioslaves assume that.
      port = 0;
-  setHost(u.host(),port,u.userName(),u.password());
+  setHost(u.host(),port,u.user(),u.pass());
 }
 
 /**
@@ -734,7 +733,7 @@ void fishProtocol::setHost(const QString & host, quint16 port, const QString & u
 
     connectionUser = user;
     connectionAuth.username = user;
-    connectionAuth.url.setUserName(user);
+    connectionAuth.url.setUser(user);
 
     connectionPort = port;
     connectionPassword = pass;
@@ -1343,7 +1342,7 @@ int fishProtocol::received(const char *buffer, KIO::fileoffset_t buflen)
     return buflen;
 }
 /** get a file */
-void fishProtocol::get(const QUrl& u){
+void fishProtocol::get(const KUrl& u){
     myDebug( << "@@@@@@@@@ get " << u << endl);
     setHostInternal(u);
     url = u;
@@ -1360,7 +1359,7 @@ void fishProtocol::get(const QUrl& u){
 }
 
 /** put a file */
-void fishProtocol::put(const QUrl& u, int permissions, KIO::JobFlags flags) {
+void fishProtocol::put(const KUrl& u, int permissions, KIO::JobFlags flags) {
     myDebug( << "@@@@@@@@@ put " << u << " " << permissions << " " << (flags & KIO::Overwrite) << " " /* << resume */ << endl);
     setHostInternal(u);
 
@@ -1520,7 +1519,7 @@ with .fishsrv.pl typically running on another computer. */
 }
 
 /** stat a file */
-void fishProtocol::stat(const QUrl& u){
+void fishProtocol::stat(const KUrl& u){
     myDebug( << "@@@@@@@@@ stat " << u << endl);
     setHostInternal(u);
     url = u;
@@ -1532,12 +1531,12 @@ void fishProtocol::stat(const QUrl& u){
     if (!url.hasPath()) {
         sendCommand(FISH_PWD);
     } else {
-		sendCommand(FISH_STAT,E(url.path(KUrl::RemoveTrailingSlash)));
+        sendCommand(FISH_STAT,E(url.path(KUrl::RemoveTrailingSlash)));
     }
     run();
 }
 /** find mimetype for a file */
-void fishProtocol::mimetype(const QUrl& u){
+void fishProtocol::mimetype(const KUrl& u){
     myDebug( << "@@@@@@@@@ mimetype " << u << endl);
     setHostInternal(u);
     url = u;
@@ -1553,7 +1552,7 @@ void fishProtocol::mimetype(const QUrl& u){
     run();
 }
 /** list a directory */
-void fishProtocol::listDir(const QUrl& u){
+void fishProtocol::listDir(const KUrl& u){
     myDebug( << "@@@@@@@@@ listDir " << u << endl);
     setHostInternal(u);
     url = u;
@@ -1569,7 +1568,7 @@ void fishProtocol::listDir(const QUrl& u){
     run();
 }
 /** create a directory */
-void fishProtocol::mkdir(const QUrl& u, int permissions) {
+void fishProtocol::mkdir(const KUrl& u, int permissions) {
     myDebug( << "@@@@@@@@@ mkdir " << u << " " << permissions << endl);
     setHostInternal(u);
     url = u;
@@ -1585,10 +1584,10 @@ void fishProtocol::mkdir(const QUrl& u, int permissions) {
     run();
 }
 /** rename a file */
-void fishProtocol::rename(const QUrl& s, const QUrl& d, KIO::JobFlags flags) {
+void fishProtocol::rename(const KUrl& s, const KUrl& d, KIO::JobFlags flags) {
     myDebug( << "@@@@@@@@@ rename " << s << " " << d << " " << (flags & KIO::Overwrite) << endl);
-    if (s.host() != d.host() || s.port() != d.port() || s.userName() != d.userName()) {
-        error(ERR_UNSUPPORTED_ACTION,s.toDisplayString());
+    if (s.host() != d.host() || s.port() != d.port() || s.user() != d.user()) {
+        error(ERR_UNSUPPORTED_ACTION,s.prettyUrl());
         return;
     }
     setHostInternal(s);
@@ -1611,7 +1610,7 @@ void fishProtocol::rename(const QUrl& s, const QUrl& d, KIO::JobFlags flags) {
     run();
 }
 /** create a symlink */
-void fishProtocol::symlink(const QString& target, const QUrl& u, KIO::JobFlags flags) {
+void fishProtocol::symlink(const QString& target, const KUrl& u, KIO::JobFlags flags) {
     myDebug( << "@@@@@@@@@ symlink " << target << " " << u << " " << (flags & KIO::Overwrite) << endl);
     setHostInternal(u);
     url = u;
@@ -1631,7 +1630,7 @@ void fishProtocol::symlink(const QString& target, const QUrl& u, KIO::JobFlags f
     run();
 }
 /** change file permissions */
-void fishProtocol::chmod(const QUrl& u, int permissions){
+void fishProtocol::chmod(const KUrl& u, int permissions){
     myDebug( << "@@@@@@@@@ chmod " << u << " " << permissions << endl);
     setHostInternal(u);
     url = u;
@@ -1646,10 +1645,10 @@ void fishProtocol::chmod(const QUrl& u, int permissions){
     run();
 }
 /** copies a file */
-void fishProtocol::copy(const QUrl &s, const QUrl &d, int permissions, KIO::JobFlags flags) {
+void fishProtocol::copy(const KUrl &s, const KUrl &d, int permissions, KIO::JobFlags flags) {
     myDebug( << "@@@@@@@@@ copy " << s << " " << d << " " << permissions << " " << (flags & KIO::Overwrite) << endl);
-    if (s.host() != d.host() || s.port() != d.port() || s.userName() != d.userName()) {
-        error(ERR_UNSUPPORTED_ACTION,s.toDisplayString());
+    if (s.host() != d.host() || s.port() != d.port() || s.user() != d.user()) {
+        error(ERR_UNSUPPORTED_ACTION,s.prettyUrl());
         return;
     }
     //myDebug( << s << endl << d << endl);
@@ -1674,14 +1673,14 @@ void fishProtocol::copy(const QUrl &s, const QUrl &d, int permissions, KIO::JobF
     run();
 }
 /** removes a file or directory */
-void fishProtocol::del(const QUrl &u, bool isFile){
+void fishProtocol::del(const KUrl &u, bool isFile){
     myDebug( << "@@@@@@@@@ del " << u << " " << isFile << endl);
     setHostInternal(u);
     url = u;
     openConnection();
     if (!isLoggedIn) return;
     url.cleanPath();
-    if (!url.path().isEmpty()) {
+    if (!url.hasPath()) {
         sendCommand(FISH_PWD);
     } else {
         sendCommand((isFile?FISH_DELE:FISH_RMD),E(url.path()));
